/*
 * Developed by Hillstone Software. http://www.hillstone-software.com
 * ICMP protocol module, interface definitions
 */
#ifndef _HS_ICMP_IF_H
#define _HS_ICMP_IF_H 

typedef enum
{
	HS_ICMP_RC_OK,					// success
	HS_ICMP_RC_BAD_PARAM,			// invlaid parameters
	HS_ICMP_RC_NOT_INIT,			// not initialized
	HS_ICMP_RC_ALR_INIT,			// already intitialized
	HS_ICMP_RC_BUSY,				// ICMP ping already in progress
} hsicmp_rc_t;

typedef enum
{
	HS_ICMP_EV_PING_TIMEOUT,		// no ping reply received
	HS_ICMP_EV_PING_SENT,			// ping request sent
	HS_ICMP_EV_PING_REPLY,			// ping reply received
	HS_ICMP_EV_PING_FINISHED,		// ping finished
} hsicmp_events_t;

typedef void hsicmp_log_fn_t(char *str);

typedef void hsicmp_timer_cb_t(void *arg);
typedef long hsicmp_timer_start_t(unsigned long timeout_ms, void *arg, hsicmp_timer_cb_t *cb);
typedef void hsicmp_timer_stop_t(long timer_han);

// event callback
typedef long hsicmp_event_fn_t(int ev, long arg1, long arg2);

// get number of millisecond ticks since bootup
typedef unsigned long  hsicmp_get_ticks_fn_t(void);

typedef struct
{
	hsicmp_timer_start_t	*start_timer;	// start timer callback
	hsicmp_timer_stop_t		*stop_timer;	// stop timer callback
	hsicmp_event_fn_t		*event_fn;		// event callback
	hsicmp_log_fn_t			*log_fn;		// event log function callback
	hsicmp_get_ticks_fn_t	*get_ticks;		// get number of millisecond ticks since bootup
} hsicmp_init_t;

/*
 * Initialize ICMP module
 */
extern int HsIcmpInit(hsicmp_init_t *init);

/*
 * De-initialize ICMP module
 */
extern void HsIcmpCleanUp(void);

/*
 * Send ICMP echo requests
 */ 
extern int HsIcmpPing(unsigned long dest_ip, unsigned long timeout_ms, int num_pings, unsigned short data_size);
/*
 * Cancel current ping in progress
 */
extern void HsIcmpCancelPing(void);

/*
 * ICMP packet received
 */
extern void HsIcmpReceivePacket(unsigned long from_ip, unsigned char *pIcmpPkt,  int length);

#endif /*_HS_ICMP_IF_H */
